const ADDON_ID = "webext-test@tests.mozilla.org";

add_task(async function install_xpi() {

  Services.prefs.setBoolPref("extensions.allow-non-mpc-extensions", true);

  // Data for WebExtension with syntax error
  let xpi1 = Extension.generateXPI({
    files: {
      "manifest.json": String.raw`{
        // This is a manifest. Intentional syntax error in next line.
        "manifest_version: 2,  
        "applications": {"gecko": {"id": "${ADDON_ID}"}},
        "name": "Temp WebExt with Error",
        "version": "0.1" 
      }`,
    },
  });

  // Data for WebExtension without syntax error
  let xpi2 = Extension.generateXPI({
    files: {
      "manifest.json": String.raw`{
        // This is a manifest.
        "manifest_version": 2,
        "applications": {"gecko": {"id": "${ADDON_ID}"}},
        "name": "Temp WebExt without Error",
        "version": "0.1" 
      }`,
    },
  });
 
  // Store dir where xpi files are generated
  let tmpDir = xpi1.parent;
  let xpi1path = xpi1.path;
  let xpi2path = xpi2.path;
  let xpi1filename = xpi1.leafName;
  let xpi2filename = xpi2.leafName;

  try {
  let install1 = await AddonManager.getInstallForFile(xpi1);
  } catch(e) {
    do_print("\n\n\t\t\t\t*** Exception caught ***\n\n");
  }

  // Replace xpi1 with xpi2 to have the same filename to reproduce install error
  xpi1.moveTo(tmpDir, xpi1.leafName + ".old");
  do_print(xpi1.path);
  xpi2.moveTo(tmpDir, xpi1filename);
  
  let install2 = await AddonManager.getInstallForFile(xpi2);
  do_check_neq(install2, null);

  xpi1.moveTo(tmpDir, xpi2filename);

  Services.prefs.clearUserPref("extensions.allow-non-mpc-extensions");
});

function run_test() {
  createAppInfo("xpcshell@tests.mozilla.org", "XPCShell", "1", "1");
  startupManager();

  run_next_test();
}
